/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.ws.addressing;

import java.net.URI;

import javax.xml.namespace.QName;

/**
 * @author chamerling - eBM WebSourcing
 * 
 */
public class WsaConstants {

    /**
     * Addressing namespace
     */
    public static final String NAMESPACE_URI = "http://www.w3.org/2005/08/addressing";

    /**
     * Addressing prefix
     */
    public static final String PREFIX = "wsa";

    /**
     * Anonymous addressing namespace
     */
    public static final String ANONYMOUS_URI = NAMESPACE_URI + "/role/anonymous";

    public static final String PETALS_ADDRESSING_URI = "http://petals.ow2.org/ws/addressing";

    public static final String PETALS_ADDRESSING_PREFIX = "petals-wsa";

    public static final QName ACTION_NOT_SUPPORTED_FAULT_QNAME = new QName(NAMESPACE_URI,
            "ActionNotSupported", PREFIX);

    public static final QName ACTION_QNAME = new QName(NAMESPACE_URI, "Action", PREFIX);

    public static final QName ADDRESS_QNAME = new QName(NAMESPACE_URI, "Address", PREFIX);

    public static final EndpointReference ANONYMOUS_EPR = new EndpointReference(URI
            .create(ANONYMOUS_URI));

    /**
     * 
     * The default identifier used for the implied resource pattern. This is
     * preferred to something like MUWS P1 ResourceId because it is generic to
     * all resource types.
     * 
     */
    public static final QName DEFAULT_RESOURCE_ID_QNAME = new QName(PETALS_ADDRESSING_URI,
            "ResourceId", PETALS_ADDRESSING_PREFIX);

    public static final QName DESTINATION_UNREACHABLE_FAULT_QNAME = new QName(NAMESPACE_URI,
            "DestinationUnreachable", PREFIX);

    /**
     * 
     * The standard EndpointReference QName - note that EPRs are <b>not</b>
     * required to use this as their root element QName when serialized to XML.
     * 
     */
    public static final QName EPR_QNAME = new QName(NAMESPACE_URI, "EndpointReference", PREFIX);

    /**
     * 
     * The name of the XSD EPR type. For EPR XML instances, use EPR_QNAME.
     * 
     */
    public static final QName EPR_TYPE_QNAME = new QName(NAMESPACE_URI, "EndpointReferenceType",
            PREFIX);

    public static final QName FAULT_TO_QNAME = new QName(NAMESPACE_URI, "FaultTo", PREFIX);

    /**
     * 
     * The wsa:Action that all fault messages should use.
     * 
     */
    public static final String FAULT_URI = NAMESPACE_URI + "/fault";

    public static final QName FROM_QNAME = new QName(NAMESPACE_URI, "From", PREFIX);

    public static final QName INVALID_HEADER_FAULT_QNAME = new QName(NAMESPACE_URI,
            "InvalidAddressingHeader", PREFIX);

    public static final String IS_REFERENCE_PARAMETER = "IsReferenceParameter";

    public static final String IS_REFERENCE_PARAMETER_QNAME = "wsa:IsReferenceParameter";

    public static final QName MESSAGE_ID_QNAME = new QName(NAMESPACE_URI, "MessageID", PREFIX);

    public static final QName METADATA_QNAME = new QName(NAMESPACE_URI, "Metadata", PREFIX);

    public static final QName PARAMETERS_QNAME = new QName(NAMESPACE_URI, "ReferenceParameters",
            PREFIX);

    public static final QName PORT_TYPE_QNAME = new QName(NAMESPACE_URI, "PortType", PREFIX);

    public static final QName PROBLEM_ACTION_QNAME = new QName(NAMESPACE_URI, "ProblemAction",
            PREFIX);

    public static final QName RELATES_TO_QNAME = new QName(NAMESPACE_URI, "RelatesTo", PREFIX);

    public static final String RELATIONSHIP_TYPE = "RelationshipType";

    public static final String REPLY_RELATIONSHIP = PREFIX + ":Reply";

    public static final QName REPLY_RELATIONSHIP_QNAME = new QName(NAMESPACE_URI, "Reply", PREFIX);

    public static final QName REPLY_TO_QNAME = new QName(NAMESPACE_URI, "ReplyTo", PREFIX);

    public static final QName SERVICE_NAME_QNAME = new QName(NAMESPACE_URI, "ServiceName", PREFIX);

    public static final String SERVICE_PORT_NAME = "PortName";

    public static final QName TO_QNAME = new QName(NAMESPACE_URI, "To", PREFIX);
}
