/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.ws.notification;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * A list of filters. This filter will accept notification if all its children
 * accept the notification message.
 *
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 *
 */
public class FilterList extends Filter {

    /**
     * List of applicable filters
     */
    protected List<Filter> filters;

    /**
     * Creates a new instance of {@link FilterList}
     *
     */
    public FilterList() {
        this.filters = new ArrayList<Filter>();
    }

    /**
     * Add a filter to the list
     *
     * @param filter
     */
    public void addFilter(Filter filter) {
        if (filter != null) {
            filters.add(filter);
        }
    }

    /*
     * (non-Javadoc)
     *
     * @see org.objectweb.petals.ws.notification.Filter#accept(org.objectweb.petals.ws.notification.NotificationMessage)
     */
    @Override
    protected boolean accept(NotificationMessage message) {
        boolean result = true;

        // go through all the filters, resutl is set to false if at least a
        // filter does not accepts the notification message
        Iterator<Filter> iter = filters.iterator();
        while (iter.hasNext() && result) {
            Filter filter = iter.next();
            result = filter.accept(message);
        }

        return result;
    }

}
