/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.ws.notification;

import java.util.List;

import org.apache.axiom.om.OMDocument;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.util.XPathEvaluator;
import org.ow2.petals.ws.fault.InvalidMessageContentExpressionFault;
import org.ow2.petals.ws.util.AxiomHelper;

/**
 * A filter based on message content validation (using xpath)
 *
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 *
 */
public class MessageContentFilter extends Filter {

    /**
     * The xpath pattern used to evaluate notification messages.
     */
    protected String xpathPattern;

    /**
     * Creates a new instance of {@link MessageContentFilter}
     *
     * @param pattern
     * @param dialect
     * @throws InvalidMessageContentExpressionFault
     */
    public MessageContentFilter(String pattern, String dialect)
            throws InvalidMessageContentExpressionFault {
        if (!dialect.equals(WsnHelper.XPATH_DIALECT_URI)) {
            throw new InvalidMessageContentExpressionFault("Invalid dialect : "
                    + dialect);
        }
        this.xpathPattern = pattern;
    }

    /*
     * (non-Javadoc)
     *
     * @see org.objectweb.petals.ws.notification.Filter#accept(org.objectweb.petals.ws.notification.NotificationMessage)
     */
    @Override
    public boolean accept(NotificationMessage message) {
        boolean result = true;
        try {
            OMElement messageElement = WsnHelper
                    .notificationMessageToOM(message);

            OMDocument document = AxiomHelper.createEmptyDocument();
            document.addChild(messageElement);

            XPathEvaluator eval = new XPathEvaluator();
            List list = eval.evaluateXpath(xpathPattern, document, null);

            // accept the message only if the evaluation returns a non empty
            // list
            result = (list.size() > 0);

        } catch (Exception e) {
            result = false;
        }
        return result;
    }
}
