/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.ws.notification;

import java.io.IOException;
import java.io.InputStream;

import javax.servlet.http.HttpServletRequest;
import javax.xml.stream.FactoryConfigurationError;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;

import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.util.StAXUtils;
import org.apache.axiom.soap.SOAPBody;
import org.apache.axiom.soap.SOAPEnvelope;
import org.apache.axiom.soap.SOAPHeader;
import org.apache.axiom.soap.impl.builder.StAXSOAPModelBuilder;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.ow2.petals.ws.addressing.WsaConstants;
import org.ow2.petals.ws.notification.handlers.request.WSNHandler;
import org.ow2.petals.ws.util.AxiomHelper;

/**
 * Isolation layer used to handle soap requests.
 *
 * @author chamerling - eBM WebSourcing
 *
 */
public class WsnIsolationLayer {

    protected WsnManager manager;
    
    protected Log logger = LogFactory.getLog(WsnIsolationLayer.class);

    /**
     * Creates a new instance of {@link WsnIsolationLayer}
     *
     * @param request
     * @param context
     */
    public WsnIsolationLayer(WsnManager manager) {
        this.manager = manager;
    }

    /**
     * Handle a HTTP request
     * 
     * @param request
     * @return
     */
    public OMElement handleRequest(HttpServletRequest request) throws Exception {
        logger.debug("Handling new HTTP request");
        OMElement reply = null;
        SOAPEnvelope envelope = parseRequest(request);
        if (envelope == null) {
            String message = "Invalid SOAP message : Can not parse the incoming message";
            logger.warn(message);
            throw new RuntimeException(message);
        }

        SOAPHeader header = envelope.getHeader();
        SOAPBody body = envelope.getBody();

        if (header == null) {
            String message = "Invalid SOAP envelope : no header element"; 
            logger.warn(message);
            throw new RuntimeException(message);
        }
        if (body == null) {
            String message = "Invalid SOAP envelope : no body element";
            logger.warn(message);
            throw new RuntimeException(message);
        }

        OMElement actionElement = header
                .getFirstChildWithName(WsaConstants.ACTION_QNAME);
        String actionURI = actionElement.getText();

        WSNHandler handler = this.manager.getHandler(actionURI);
        if (handler != null) {
            reply = handler.handle(envelope);
        } else {
            reply = unknownAction(envelope);
        }

        return reply;
    }

    /**
     *
     * @param request
     * @return
     * @throws Exception
     */
    protected SOAPEnvelope parseRequest(HttpServletRequest request) {
        logger.debug("Parse the HTTP request");
        SOAPEnvelope envelope = null;
        
        try {
            InputStream toSOAP = request.getInputStream();
            XMLStreamReader parser = StAXUtils.getXMLInputFactory().createXMLStreamReader(toSOAP);
            StAXSOAPModelBuilder builder = new StAXSOAPModelBuilder(parser,
                    null);
            envelope = (SOAPEnvelope) builder.getDocumentElement();

        } catch (IOException e) {
            logger.error("Error while parsing request to SOAPEnvelope", e);
        } catch (XMLStreamException e) {
            logger.error("Error while parsing request to SOAPEnvelope", e);
        } catch (FactoryConfigurationError e) {
            logger.error("Error while parsing request to SOAPEnvelope", e);
        }
        return envelope;
    }

    /**
     * Create an unknown action SOAPEnvelope message
     * 
     * @param envelope
     * @return
     */
    protected SOAPEnvelope unknownAction(SOAPEnvelope envelope) {
        SOAPEnvelope result = AxiomHelper.createSOAPEnvelope();
        // TODO !
        return result;
    }
}
