/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.ws.topic;

import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.ow2.petals.ws.fault.WsnFault;

/**
 * The collection of Topics supported by the NotificationProducer
 * 
 * @author chamerling - eBM WebSourcing
 * 
 */
public class TopicSet {

    protected Map<String, TopicNamespace> topicSpacesByNS;

    /**
     * Creates a new instance of {@link TopicSet}
     */
    public TopicSet() {
        this.topicSpacesByNS = new HashMap<String, TopicNamespace>();
    }

    /**
     * 
     * @param topicSpace
     * @throws Exception
     */
    public synchronized final void addTopicNamespace(TopicNamespace topicSpace)
            throws WsnFault {
        if (topicSpace == null) {
            throw new NullPointerException("");
        }

        String namespace = topicSpace.getTargetNamespace();

        if (topicSpacesByNS.keySet().contains(namespace)) {
            throw new WsnFault("Can not add topic namespace");
        }

        topicSpacesByNS.put(namespace, topicSpace);
    }

    /**
     * 
     * @param namespace
     * @return
     */
    public synchronized final TopicNamespace getTopicNamespace(String namespace) {
        return topicSpacesByNS.get(namespace);
    }

    /**
     * 
     * @return
     */
    public synchronized final Collection getTopicNamespaceURIs() {
        return Collections.unmodifiableCollection(topicSpacesByNS.keySet());
    }

    /**
     * 
     * @param namespace
     */
    public synchronized void removeTopicNamespace(String namespace) {
        if (namespace == null) {
            throw new NullPointerException("");
        }
        topicSpacesByNS.remove(namespace);
    }
}
